@@ -1,39 +1,15 @@
-from pybedtools import Interval
 from pyfaidx import Sequence, complement
-from kipoiseq.extractors import BaseExtractor, FastaStringExtractor
-try:
-    from cyvcf2 import VCF
-except ImportError:
-    VCF = object
+from kipoiseq.dataclasses import Interval
+from kipoiseq.extractors import BaseExtractor, FastaStringExtractor, \
+    MultiSampleVCF
 
 __all__ = [
     'VariantSeqExtractor',
-    'MultiSampleVCF',
     'SingleVariantVCFSeqExtractor',
     'SingleSeqVCFSeqExtractor'
 ]
 
 
-class MultiSampleVCF(VCF):
-
-    def __init__(self, *args, **kwargs):
-        from cyvcf2 import VCF
-        super(MultiSampleVCF, self).__init__(*args, **kwargs)
-        self.sample_mapping = dict(zip(self.samples, range(len(self.samples))))
-
-    def fetch_variants(self, interval, sample_id=None):
-        for v in self(self._region(interval)):
-            if sample_id is None or self._has_variant(v, sample_id):
-                yield v
-
-    def _region(self, interval):
-        return '%s:%d-%d' % (interval.chrom, interval.start, interval.end)
-
-    def _has_variant(self, variant, sample_id):
-        gt_type = variant.gt_types[self.sample_mapping[sample_id]]
-        return gt_type != 0 and gt_type != 2
-
-
 class IntervalSeqBuilder(list):
     """
     String builder for `pyfaidx.Sequence` and `Interval` objects.
@@ -166,11 +142,10 @@ class VariantSeqExtractor(BaseExtractor):
         for reference and variants.
         """
         for v in variants:
-            ref = Sequence(name=v.CHROM, seq=v.REF,
-                           start=v.start, end=v.start + len(v.REF))
-            # TO DO: consider alternative alleles.
-            alt = Sequence(name=v.CHROM, seq=v.ALT[0],
-                           start=v.start, end=v.start + len(v.ALT[0]))
+            ref = Sequence(name=v.chrom, seq=v.ref,
+                           start=v.start, end=v.start + len(v.ref))
+            alt = Sequence(name=v.chrom, seq=v.alt,
+                           start=v.start, end=v.start + len(v.alt))
             yield ref, alt
 
     def _split_overlapping(self, variant_pairs, anchor, which='both'):
